import 'dart:convert';

import 'package:syncrow_web/pages/auth/model/region_model.dart';
import 'package:syncrow_web/pages/auth/model/token.dart';
import 'package:syncrow_web/services/api/http_service.dart';
import 'package:syncrow_web/utils/constants/api_const.dart';

class AuthenticationAPI {

  static Future<Token> loginWithEmail({required var model}) async {
    final response = await HTTPService().post(
        path: ApiEndpoints.login,
        body: model.toJson(),
        showServerMessage: true,
        expectedResponseModel: (json) {
          return Token.fromJson(json['data']);
        });
    return response;
  }

  static Future forgetPassword(
      {required var email, required var password}) async {
    final response = await HTTPService().post(
        path: ApiEndpoints.forgetPassword,
        body: {"email": email, "password": password},
        showServerMessage: true,
        expectedResponseModel: (json) {});
    return response;
  }

  static Future sendOtp({required var email}) async {
    final response = await HTTPService().post(
        path: ApiEndpoints.sendOtp,
        body: {"email": email, "type": "VERIFICATION"},
        showServerMessage: true,
        expectedResponseModel: (json) {});
    return response;
  }

  static Future<bool> verifyOtp(
      {required String email, required String otpCode}) async {
    final response = await HTTPService().post(
        path: ApiEndpoints.verifyOtp,
        body: {"email": email, "type": "VERIFICATION", "otpCode": otpCode},
        showServerMessage: true,
        expectedResponseModel: (json) {
          if (json['message'] == 'Otp Verified Successfully') {
            return true;
          } else {
            return false;
          }
        });
    return response;
  }

  static Future<List<RegionModel>> fetchRegion() async {
    final response = await HTTPService().get(
        path: ApiEndpoints.getRegion,
        showServerMessage: true,
        expectedResponseModel: (json) {
          return (json as List).map((zone) => RegionModel.fromJson(zone)).toList();
        }
    );
    return response as List<RegionModel>;
  }

}
